@@ -232,15 +232,19 @@ class Aphantasia(ImageGenerator):
     def get_img_from_latents(
         self,
         latents,
+        target_img_height=None,
+        target_img_width=None,
     ):
         shift = None
 
-        height, width = self.get_img_size_from_latents(latents, )
+        if target_img_height is None or target_img_width is None:
+            target_img_height, target_img_width = self.get_img_size_from_latents(
+                latents, )
 
         #NOTE: generat all possible freqs for the input image size
         img_freqs = self.compute_2d_img_freqs(
-            height=height,
-            width=width,
+            height=target_img_height,
+            width=target_img_width,
         )
 
         scale = self.get_scale_from_img_freqs(
@@ -251,8 +255,8 @@ class Aphantasia(ImageGenerator):
         img = self.fft_to_rgb(
             fft_img=latents,
             scale=scale,
-            height=height,
-            width=width,
+            height=target_img_height,
+            width=target_img_width,
             shift=shift,
             contrast=1.0,
             decorrelate=True,
