@@ -194,15 +194,14 @@ class TamingDecoder(ImageGenerator):
             img_tensor = img
         else:
             img = img.convert('RGB')
-
             img_tensor = torch.tensor(np.asarray(img))
+            img_tensor = img_tensor.permute(2, 0, 1)
+            img_tensor = (img_tensor / 255.) * 2 - 1
 
         if len(img_tensor.shape) <= 3:
             img_tensor = img_tensor[None, ::]
 
         img_tensor = img_tensor.float().to(self.device)
-        img_tensor = (img_tensor / 255.) * 2 - 1
-        img_tensor = img_tensor.permute(0, 3, 1, 2)
 
         z, _, [_, _, _indices] = self.vqgan_model.encode(img_tensor)
 
